@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.095-7-g8837c64
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.096-11-g50c16e5
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.096';
+our $VERSION = '0.097';
 
 use Moose;
 with
@@ -65,7 +65,7 @@ has copy_file_from_release => (
 
 around copy_files_from_release => sub {
     my $orig = shift; my $self = shift;
-    _uniq($self->$orig(@_), qw(LICENSE CONTRIBUTING Changes ppport.h));
+    _uniq($self->$orig(@_), qw(LICENSE CONTRIBUTING Changes ppport.h INSTALL));
 };
 
 has changes_version_columns => (
@@ -104,7 +104,8 @@ my $has_bash = can_run('bash');
 # files that might be in the repository that should never be gathered
 my @never_gather = qw(
     Makefile.PL ppport.h README.md README.pod META.json
-    cpanfile TODO CONTRIBUTING LICENSE inc/ExtUtils/MakeMaker/Dist/Zilla/Develop.pm
+    cpanfile TODO CONTRIBUTING LICENSE INSTALL
+    inc/ExtUtils/MakeMaker/Dist/Zilla/Develop.pm
 );
 
 around BUILDARGS => sub
@@ -140,7 +141,7 @@ sub configure
     warn '[@Author::ETHER] ' . colored('bin/ detected - should this be moved to script/, so its contents can be installed into $PATH?', 'bright_red') . "\n"
         if -d 'bin' and any { $_ eq 'ModuleBuildTiny' } $self->installer;
 
-    warn '[@Author::ETHER] You are using [ModuleBuild] as an installer, WTF?!'
+    warn '[@Author::ETHER] ' . colored('You are using [ModuleBuild] as an installer, WTF?!', 'bright_red') . "\n"
         if any { $_ eq 'ModuleBuild' } $self->installer;
 
     # this is better than injecting a perl prereq for 5.008, to allow MBT to
@@ -153,6 +154,11 @@ sub configure
     my $remove = $self->payload->{ $self->plugin_remover_attribute } // [];
     my %removed; @removed{@$remove} = (!!1) x @$remove;
 
+    warn '[@Author::ETHER] ' . colored('.git is missing and META.json is present -- this looks like a CPAN download rather than a git repository. You should probably run '
+            . (-f 'Build.PL' ? 'perl Build.PL; ./Build' : 'perl Makefile.PL; make') . ' instead of using dzil commands!', 'yellow') . "\n"
+        if not -d '.git' and -f 'META.json' and not exists $removed{'Git::GatherDir'};
+
+
     my @plugins = (
         # VersionProvider
         [ 'RewriteVersion::Transitional' => { ':version' => '0.004', global => 1, fallback_version_provider => 'Git::NextVersion', version_regexp => '^v([\d._]+)(-TRIAL)?$',
@@ -185,7 +191,7 @@ sub configure
         [ 'Test::Compile'       => { ':version' => '2.039', bail_out_on_fail => 1, xt_mode => 1,
             script_finder => [qw(:ExecFiles @Author::ETHER/Examples)] } ],
         [ 'Test::NoTabs'        => { ':version' => '0.08', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles @Author::ETHER/ExtraTestFiles)] } ],
-        [ 'Test::EOL'           => { ':version' => '0.14', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles @Author::ETHER/ExtraTestFiles)] } ],
+        [ 'Test::EOL'           => { ':version' => '0.17', finder => [qw(:InstallModules :ExecFiles @Author::ETHER/Examples :TestFiles @Author::ETHER/ExtraTestFiles)] } ],
         'MetaTests',
         [ 'Test::CPAN::Changes' => { ':version' => '0.008' } ],
         'Test::ChangesHasContent',
@@ -257,7 +263,7 @@ sub configure
         'CheckSelfDependency',
 
         ( $has_bash ?
-            [ 'Run::AfterBuild' => '.ackrc' => { ':version' => '0.038', quiet => 1, run => q{bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname %d` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi"} } ]
+            [ 'Run::AfterBuild' => '.ackrc' => { ':version' => '0.038', quiet => 1, run => q{bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname '%d'` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi"} } ]
             : ()),
         [ 'Run::AfterBuild'     => '.latest' => { ':version' => '0.038', quiet => 1, eval => q!if ('%d' =~ /^%n-[.[:xdigit:]]+$/) { unlink '.latest'; symlink '%d', '.latest'; }! } ],
 
@@ -388,7 +394,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.096
+version 0.097
 
 =head1 SYNOPSIS
 
@@ -436,16 +442,17 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     ;;; Gather Files
     [Git::GatherDir]
     :version = 2.016
+    exclude_filename = CONTRIBUTING
+    exclude_filename = INSTALL
+    exclude_filename = LICENSE
+    exclude_filename = META.json
     exclude_filename = Makefile.PL
-    exclude_filename = ppport.h
     exclude_filename = README.md
     exclude_filename = README.pod
-    exclude_filename = META.json
-    exclude_filename = cpanfile
     exclude_filename = TODO
-    exclude_filename = CONTRIBUTING
-    exclude_filename = LICENSE
+    exclude_filename = cpanfile
     exclude_filename = inc/ExtUtils/MakeMaker/Dist/Zilla/Develop.pm
+    exclude_filename = ppport.h
 
     [MetaYAML]
     [MetaJSON]
@@ -474,7 +481,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     finder = ExtraTestFiles
 
     [Test::EOL]
-    :version = 0.14
+    :version = 0.17
     finder = :InstallModules
     finder = :ExecFiles
     finder = Examples
@@ -541,16 +548,16 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     do_munging = 0
 
     [MetaNoIndex]
-    directory = t
-    directory = xt
+    directory = corpus
+    directory = demo
+    directory = examples
+    directory = fatlib
     directory = inc
     directory = local
     directory = perl5
-    directory = fatlib
-    directory = examples
     directory = share
-    directory = corpus
-    directory = demo
+    directory = t
+    directory = xt
 
     [MetaProvides::Package]
     :version = 1.15000002
@@ -590,7 +597,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
 
     ;;; Test Runner
-    # <specified installer(s)>
+    ; <specified installer(s)>
     [RunExtraTests]
     :version = 0.024
     default_jobs = 9
@@ -602,7 +609,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [Run::AfterBuild / .ackrc]
     :version = 0.38
     quiet = 1
-    run = bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname %d` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi; if [[ %d =~ ^%n-[.[:xdigit:]]+$ ]]; then rm -f .latest; ln -s %d .latest; fi"
+    run = bash -c "test -e .ackrc && grep -q -- '--ignore-dir=.latest' .ackrc || echo '--ignore-dir=.latest' >> .ackrc; if [[ `dirname '%d'` != .build ]]; then test -e .ackrc && grep -q -- '--ignore-dir=%d' .ackrc || echo '--ignore-dir=%d' >> .ackrc; fi; if [[ %d =~ ^%n-[.[:xdigit:]]+$ ]]; then rm -f .latest; ln -s %d .latest; fi"
     [Run::AfterBuild / .latest]
     :version = 0.038
     quiet = 1
@@ -640,9 +647,10 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
     ;;; AfterRelease
     [CopyFilesFromRelease]
-    filename = LICENSE
     filename = CONTRIBUTING
     filename = Changes
+    filename = INSTALL
+    filename = LICENSE
     filename = ppport.h
 
     [Run::AfterRelease / remove old READMEs]
@@ -653,11 +661,12 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [Git::Commit / release snapshot]
     :version = 2.020
     add_files_in = .
+    allow_dirty = CONTRIBUTING
     allow_dirty = Changes
+    allow_dirty = INSTALL
+    allow_dirty = LICENSE
     allow_dirty = README.md
     allow_dirty = README.pod
-    allow_dirty = LICENSE
-    allow_dirty = CONTRIBUTING
     allow_dirty = ppport.h
     commit_msg = %N-%v%t%n%n%c
 
