@@ -4,11 +4,11 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.096';
+our $VERSION = '0.097';
 
 use namespace::autoclean -also => ['_exp'];
-
 use Pod::Weaver::Config::Assembler;
+
 sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
 
 sub configure
@@ -35,6 +35,7 @@ sub configure
         [ 'Collect' => 'ATTRIBUTES' => { command => 'attr' } ],
         [ 'Collect' => 'METHODS'    => { command => 'method' } ],
         [ 'Collect' => 'FUNCTIONS'  => { command => 'func' } ],
+        [ 'Collect' => 'TYPES'      => { command => 'type' } ],
         'Leftovers',
         [ 'Region' => 'postlude' ],
         'Authors',
@@ -122,7 +123,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.096
+version 0.097
 
 =head1 SYNOPSIS
 
@@ -173,6 +174,9 @@ following F<weaver.ini>, minus some optimizations:
     [Collect / FUNCTIONS]
     command = func
 
+    [Collect / TYPES]
+    command = type
+
     [Leftovers]
 
     [Region / postlude]
@@ -191,8 +195,13 @@ This is also equivalent (other than section ordering) to:
 
     [Region / header]
     [@Default]
+
+    [Collect / TYPES]
+    command = type
+
     [Contributors]
     :version = 0.008
+
     [Region / footer]
 
 =head1 OPTIONS / OVERRIDES
